package net.knarcraft.placeholdersigns.listener;

import net.knarcraft.placeholdersigns.PlaceholderSigns;
import net.knarcraft.placeholdersigns.container.LineChangeRequest;
import org.bukkit.Bukkit;
import org.bukkit.block.Sign;
import org.bukkit.event.EventHandler;
import org.bukkit.event.EventPriority;
import org.bukkit.event.Listener;
import org.bukkit.event.block.SignChangeEvent;
import org.bukkit.event.player.PlayerInteractEvent;

/**
 * A listener for placeholder signs being clicked
 */
public class SignClickListener implements Listener {

    @EventHandler(priority = EventPriority.MONITOR)
    public void onSignClick(PlayerInteractEvent event) {
        // Ignore if not a clicked sign
        if (!event.hasBlock() || event.getClickedBlock() == null ||
                !(event.getClickedBlock().getState() instanceof Sign sign)) {
            return;
        }


        // Check if the player has run the /editSign command
        LineChangeRequest request = PlaceholderSigns.getInstance().getChangeRequest(event.getPlayer());
        if (request == null) {
            return;
        }

        String[] lines = sign.getLines();
        lines[request.line()] = request.text();

        // Run the sign change event to allow protection plugins to cancel, and allow the sign text listener to trigger
        SignChangeEvent changeEvent = new SignChangeEvent(event.getClickedBlock(), event.getPlayer(), lines);
        Bukkit.getPluginManager().callEvent(changeEvent);
        if (changeEvent.isCancelled()) {
            return;
        }

        // Update the sign with the new text
        String[] finalLines = changeEvent.getLines();
        for (int i = 0; i < finalLines.length; i++) {
            sign.setLine(i, finalLines[i]);
        }
        sign.update();

        event.getPlayer().sendMessage("The sign line was successfully changed.");
    }

}
